.. _user:

##########
User guide
##########

.. toctree::
    :maxdepth: 1

    organisation

    quickstart

    installation

    usage

    library

    performance

    Templates <templates/index>